// src/use-frame-stack.ts
import { useReducer } from "react";
function isParseResult(result) {
  return "status" in result;
}
function framesStackReducer(state, action) {
  switch (action.action) {
    case "LOAD":
      return [action.item, ...state];
    case "ADD_REQUEST_DETAILS": {
      const index = state.findIndex(
        (item2) => item2.timestamp === action.pendingItem.timestamp
      );
      if (index === -1) {
        return state;
      }
      const item = state[index];
      if (!item || item.status !== "pending") {
        return state;
      }
      state[index] = {
        ...item,
        requestDetails: action.requestDetails,
        url: action.url
      };
      return state.slice();
    }
    case "DONE_REDIRECT": {
      const index = state.findIndex(
        (item) => item.timestamp === action.pendingItem.timestamp
      );
      if (index === -1) {
        return state;
      }
      state[index] = {
        ...action.pendingItem,
        ...action.item,
        status: "doneRedirect"
      };
      return state.slice();
    }
    case "DONE":
    case "REQUEST_ERROR": {
      const index = state.findIndex(
        (item) => item.timestamp === action.pendingItem.timestamp
      );
      if (index === -1) {
        return state;
      }
      state[index] = action.item;
      return state.slice();
    }
    case "RESET_INITIAL_FRAME": {
      const originalInitialFrame = state[0];
      const frame = isParseResult(action.resultOrFrame) ? action.resultOrFrame.frame : action.resultOrFrame;
      const shouldReset = !originalInitialFrame || originalInitialFrame.status === "done" && originalInitialFrame.frameResult.frame !== frame;
      if (shouldReset) {
        const frameResult = isParseResult(action.resultOrFrame) ? action.resultOrFrame : {
          status: "success",
          reports: {},
          frame: action.resultOrFrame
        };
        return [
          {
            request: {
              method: "GET",
              url: action.homeframeUrl ?? ""
            },
            url: action.homeframeUrl ?? "",
            requestDetails: {},
            response: new Response(JSON.stringify(frameResult), {
              status: 200,
              headers: { "Content-Type": "application/json" }
            }),
            responseStatus: 200,
            timestamp: /* @__PURE__ */ new Date(),
            speed: 0,
            frameResult,
            status: "done",
            // @todo should this be result or frame?
            responseBody: frameResult
          }
        ];
      }
      return state;
    }
    case "CLEAR":
      return [];
    default:
      return state;
  }
}
function useFrameStack({
  initialFrame,
  initialFrameUrl
}) {
  return useReducer(
    framesStackReducer,
    [initialFrame, initialFrameUrl],
    ([frame, frameUrl]) => {
      if (frame) {
        const frameResult = isParseResult(frame) ? frame : {
          reports: {},
          frame,
          status: "success"
        };
        return [
          {
            response: new Response(JSON.stringify(frameResult), {
              status: 200,
              headers: { "Content-Type": "application/json" }
            }),
            responseStatus: 200,
            responseBody: frameResult,
            timestamp: /* @__PURE__ */ new Date(),
            requestDetails: {},
            request: {
              method: "GET",
              url: frameUrl ?? ""
            },
            speed: 0,
            frameResult,
            status: "done",
            url: frameUrl ?? ""
          }
        ];
      } else if (frameUrl) {
        return [
          {
            method: "GET",
            request: {
              method: "GET",
              url: frameUrl
            },
            url: frameUrl,
            requestDetails: {},
            timestamp: /* @__PURE__ */ new Date(),
            status: "pending"
          }
        ];
      }
      return [];
    }
  );
}

export {
  isParseResult,
  useFrameStack
};
