"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/farcaster/frames.tsx
var frames_exports = {};
__export(frames_exports, {
  createFrameActionMessageWithSignerKey: () => createFrameActionMessageWithSignerKey,
  signFrameAction: () => signFrameAction
});
module.exports = __toCommonJS(frames_exports);
var import_core = require("@farcaster/core");
var import_viem = require("viem");
var signFrameAction = async ({
  buttonIndex,
  frameContext,
  frameButton,
  signer,
  target,
  inputText,
  state,
  transactionId,
  url
}) => {
  if (!signer || signer.status === "pending_approval") {
    throw new Error("Missing signer fid to sign message");
  }
  const { message, trustedBytes } = await createFrameActionMessageWithSignerKey(
    signer.privateKey,
    {
      fid: signer.fid,
      buttonIndex,
      castId: {
        fid: frameContext.castId.fid,
        hash: (0, import_viem.hexToBytes)(frameContext.castId.hash)
      },
      state: state !== void 0 ? Buffer.from(state) : void 0,
      url: Buffer.from(url),
      // it seems the message in hubs actually requires a value here.
      inputText: inputText !== void 0 ? Buffer.from(inputText) : void 0,
      address: frameContext.address !== void 0 ? (0, import_viem.hexToBytes)(frameContext.address) : void 0,
      transactionId: transactionId !== void 0 ? (0, import_viem.hexToBytes)(transactionId) : void 0
    }
  );
  if (!message) {
    throw new Error("hub error");
  }
  const searchParams = new URLSearchParams({
    postType: transactionId ? "post" : frameButton.action,
    postUrl: target ?? ""
  });
  return {
    searchParams,
    body: {
      untrustedData: {
        fid: signer.fid,
        url,
        messageHash: `0x${Buffer.from(message.hash).toString("hex")}`,
        timestamp: message.data.timestamp,
        network: 1,
        buttonIndex: Number(message.data.frameActionBody.buttonIndex),
        castId: {
          fid: frameContext.castId.fid,
          hash: frameContext.castId.hash
        },
        inputText,
        address: frameContext.address,
        transactionId,
        state
      },
      trustedData: {
        messageBytes: trustedBytes
      }
    }
  };
};
async function createFrameActionMessageWithSignerKey(signerKey, {
  fid,
  url,
  buttonIndex,
  castId,
  inputText,
  state,
  address,
  transactionId
}) {
  const signer = new import_core.NobleEd25519Signer(Buffer.from(signerKey.slice(2), "hex"));
  const messageDataOptions = {
    fid,
    network: import_core.FarcasterNetwork.MAINNET
  };
  const message = await (0, import_core.makeFrameAction)(
    import_core.FrameActionBody.create({
      url,
      buttonIndex,
      castId,
      state,
      inputText: inputText !== void 0 ? Buffer.from(inputText) : void 0,
      address,
      transactionId
    }),
    messageDataOptions,
    signer
  );
  if (message.isErr()) {
    return { message: null, trustedBytes: null };
  }
  const trustedBytes = Buffer.from(
    import_core.Message.encode(message._unsafeUnwrap()).finish()
  ).toString("hex");
  return { message: message.unwrapOr(null), trustedBytes };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  createFrameActionMessageWithSignerKey,
  signFrameAction
});
