"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/frame-ui.tsx
var frame_ui_exports = {};
__export(frame_ui_exports, {
  FrameUI: () => FrameUI,
  defaultTheme: () => defaultTheme
});
module.exports = __toCommonJS(frame_ui_exports);
var import_react = __toESM(require("react"), 1);
var defaultTheme = {
  buttonBg: "#fff",
  buttonBorderColor: "#ccc",
  buttonHoverBg: "#efefef",
  buttonColor: "#444",
  buttonRadius: "4",
  bg: "#efefef"
};
var messageSquareIcon = /* @__PURE__ */ import_react.default.createElement(
  "svg",
  {
    xmlns: "http://www.w3.org/2000/svg",
    "aria-hidden": "true",
    width: "16",
    height: "16",
    viewBox: "0 0 24 24",
    fill: "none",
    stroke: "currentColor",
    strokeWidth: "2",
    strokeLinecap: "round",
    strokeLinejoin: "round"
  },
  /* @__PURE__ */ import_react.default.createElement("path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z" })
);
var octagonXIcon = /* @__PURE__ */ import_react.default.createElement(
  "svg",
  {
    xmlns: "http://www.w3.org/2000/svg",
    width: "16",
    height: "16",
    viewBox: "0 0 24 24",
    fill: "none",
    stroke: "currentColor",
    strokeWidth: "2",
    strokeLinecap: "round",
    strokeLinejoin: "round"
  },
  /* @__PURE__ */ import_react.default.createElement("polygon", { points: "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2" }),
  /* @__PURE__ */ import_react.default.createElement("path", { d: "m15 9-6 6" }),
  /* @__PURE__ */ import_react.default.createElement("path", { d: "m9 9 6 6" })
);
var getThemeWithDefaults = (theme) => {
  return {
    ...defaultTheme,
    ...theme
  };
};
function MessageTooltip({
  inline = false,
  message,
  variant = "message"
}) {
  return /* @__PURE__ */ import_react.default.createElement(
    "div",
    {
      className: `${inline ? "" : "absolute bottom-2 border border-slate-100 rounded-sm shadow-md inset-x-2 bg-white"} ${variant === "error" ? "text-red-500" : ""} items-center p-2 flex gap-2 text-sm`
    },
    variant === "message" ? messageSquareIcon : octagonXIcon,
    message
  );
}
function getErrorMessageFromFramesStackItem(item) {
  if (item.status === "message") {
    return item.message;
  }
  if (item.requestError instanceof Error) {
    return item.requestError.message;
  }
  return "An error occurred";
}
function FrameUI({
  frameState,
  theme,
  FrameImage,
  allowPartialFrame,
  enableImageDebugging
}) {
  const [isImageLoading, setIsImageLoading] = (0, import_react.useState)(true);
  const currentFrame = frameState.currentFrameStackItem;
  const isLoading = currentFrame?.status === "pending" || isImageLoading;
  const resolvedTheme = getThemeWithDefaults(theme ?? {});
  if (!frameState.homeframeUrl) {
    return /* @__PURE__ */ import_react.default.createElement(MessageTooltip, { inline: true, message: "Missing frame url", variant: "error" });
  }
  if (!currentFrame) {
    return null;
  }
  if (currentFrame.status === "done" && currentFrame.frameResult.status === "failure" && !(allowPartialFrame && // Need at least image and buttons to render a partial frame
  currentFrame.frameResult.frame.image && currentFrame.frameResult.frame.buttons)) {
    return /* @__PURE__ */ import_react.default.createElement(MessageTooltip, { inline: true, message: "Invalid frame", variant: "error" });
  }
  let frame;
  let debugImage;
  if (currentFrame.status === "done") {
    frame = currentFrame.frameResult.frame;
    debugImage = enableImageDebugging ? currentFrame.frameResult.framesDebugInfo?.image : void 0;
  } else if (currentFrame.status === "message" || currentFrame.status === "doneRedirect") {
    frame = currentFrame.request.sourceFrame;
  } else if (currentFrame.status === "requestError") {
    frame = "sourceFrame" in currentFrame.request ? currentFrame.request.sourceFrame : void 0;
  }
  const ImageEl = FrameImage ? FrameImage : "img";
  return /* @__PURE__ */ import_react.default.createElement(
    "div",
    {
      style: { backgroundColor: resolvedTheme.bg },
      className: "flex flex-col w-full gap-2 rounded-br rounded-bl"
    },
    /* @__PURE__ */ import_react.default.createElement("div", { className: "relative w-full", style: { height: "100%" } }, " ", currentFrame.status === "message" ? /* @__PURE__ */ import_react.default.createElement(
      MessageTooltip,
      {
        inline: !frame || !("image" in frame) || !frame.image,
        message: getErrorMessageFromFramesStackItem(currentFrame),
        variant: currentFrame.type === "error" ? "error" : "message"
      }
    ) : null, !!frame && !!frame.image && /* @__PURE__ */ import_react.default.createElement(
      ImageEl,
      {
        src: debugImage ?? frame.image,
        key: debugImage ?? frame.image,
        alt: "Frame image",
        width: "100%",
        style: {
          filter: isLoading ? "blur(4px)" : void 0,
          borderTopLeftRadius: `${resolvedTheme.buttonRadius}px`,
          borderTopRightRadius: `${resolvedTheme.buttonRadius}px`,
          border: `1px solid ${resolvedTheme.buttonBorderColor}`,
          objectFit: "cover",
          width: "100%",
          aspectRatio: (frame.imageAspectRatio ?? "1.91:1") === "1:1" ? "1/1" : "1.91/1"
        },
        onLoadStart: () => {
          setIsImageLoading(true);
        },
        onLoad: () => {
          setIsImageLoading(false);
        },
        onError: () => {
          setIsImageLoading(false);
        }
      }
    )),
    !!frame && frame.inputText ? /* @__PURE__ */ import_react.default.createElement(
      "input",
      {
        className: "p-[6px] mx-2 border box-border",
        style: {
          borderRadius: `${resolvedTheme.buttonRadius}px`,
          borderColor: `${resolvedTheme.buttonBorderColor}`
        },
        value: frameState.inputText,
        type: "text",
        placeholder: frame.inputText,
        onChange: (e) => {
          frameState.setInputText(e.target.value);
        }
      }
    ) : null,
    !!frame && !!frame.buttons && frame.buttons.length > 0 ? /* @__PURE__ */ import_react.default.createElement("div", { className: "flex gap-[8px] px-2 pb-2" }, frame.buttons.map((frameButton, index) => /* @__PURE__ */ import_react.default.createElement(
      "button",
      {
        type: "button",
        disabled: isLoading,
        className: `p-2 ${isLoading ? "bg-gray-100" : ""} border text-sm text-gray-800 rounded`,
        style: {
          flex: "1 1 0px",
          // fixme: hover style
          backgroundColor: resolvedTheme.buttonBg,
          borderColor: resolvedTheme.buttonBorderColor,
          color: resolvedTheme.buttonColor,
          cursor: isLoading ? void 0 : "pointer"
        },
        onClick: () => {
          Promise.resolve(
            frameState.onButtonPress(
              // Partial frame could have enough data to handle button press
              frame,
              frameButton,
              index
            )
          ).catch((e) => {
            console.error(e);
          });
        },
        key: index
      },
      frameButton.action === "mint" ? `\u2B17 ` : "",
      frameButton.label,
      frameButton.action === "tx" ? /* @__PURE__ */ import_react.default.createElement(
        "svg",
        {
          "aria-hidden": "true",
          focusable: "false",
          role: "img",
          viewBox: "0 0 16 16",
          className: "ml-1 mb-[2px] text-gray-400 inline-block select-none align-text-middle overflow-visible",
          width: "12",
          height: "12",
          fill: "currentColor"
        },
        /* @__PURE__ */ import_react.default.createElement("path", { d: "M9.504.43a1.516 1.516 0 0 1 2.437 1.713L10.415 5.5h2.123c1.57 0 2.346 1.909 1.22 3.004l-7.34 7.142a1.249 1.249 0 0 1-.871.354h-.302a1.25 1.25 0 0 1-1.157-1.723L5.633 10.5H3.462c-1.57 0-2.346-1.909-1.22-3.004L9.503.429Zm1.047 1.074L3.286 8.571A.25.25 0 0 0 3.462 9H6.75a.75.75 0 0 1 .694 1.034l-1.713 4.188 6.982-6.793A.25.25 0 0 0 12.538 7H9.25a.75.75 0 0 1-.683-1.06l2.008-4.418.003-.006a.036.036 0 0 0-.004-.009l-.006-.006-.008-.001c-.003 0-.006.002-.009.004Z" })
      ) : "",
      frameButton.action === "post_redirect" || frameButton.action === "link" ? ` \u2197` : ""
    ))) : null
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  FrameUI,
  defaultTheme
});
