"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/next/index.tsx
var next_exports = {};
__export(next_exports, {
  FrameImageNext: () => FrameImageNext,
  GET: () => GET,
  POST: () => POST
});
module.exports = __toCommonJS(next_exports);

// src/next/GET.tsx
var import_frames = require("frames.js");

// src/next/validators.ts
function isSpecificationValid(specification) {
  return typeof specification === "string" && ["farcaster", "openframes"].includes(specification);
}

// src/next/GET.tsx
async function GET(request) {
  const searchParams = "nextUrl" in request ? request.nextUrl.searchParams : new URL(request.url).searchParams;
  const url = searchParams.get("url");
  const specification = searchParams.get("specification") ?? "farcaster";
  if (!url) {
    return Response.json({ message: "Invalid URL" }, { status: 400 });
  }
  if (!isSpecificationValid(specification)) {
    return Response.json({ message: "Invalid specification" }, { status: 400 });
  }
  try {
    const urlRes = await fetch(url);
    const htmlString = await urlRes.text();
    const result = (0, import_frames.getFrame)({ htmlString, url, specification });
    return Response.json(result);
  } catch (err) {
    console.error(err);
    return Response.json({ message: err }, { status: 500 });
  }
}

// src/next/POST.tsx
var import_frames2 = require("frames.js");
async function POST(req) {
  const searchParams = "nextUrl" in req ? req.nextUrl.searchParams : new URL(req.url).searchParams;
  const body = await req.json();
  const isPostRedirect = searchParams.get("postType") === "post_redirect";
  const isTransactionRequest = searchParams.get("postType") === "tx";
  const postUrl = searchParams.get("postUrl");
  const specification = searchParams.get("specification") ?? "farcaster";
  if (!postUrl) {
    return Response.error();
  }
  if (!isSpecificationValid(specification)) {
    return Response.json({ message: "Invalid specification" }, { status: 400 });
  }
  try {
    const r = await fetch(postUrl, {
      method: "POST",
      headers: {
        Accept: "application/json",
        "Content-Type": "application/json"
      },
      redirect: isPostRedirect ? "manual" : void 0,
      body: JSON.stringify(body)
    });
    if (r.status >= 500) {
      return r;
    }
    if (r.status === 302) {
      return Response.json(
        {
          location: r.headers.get("location")
        },
        { status: 302 }
      );
    }
    if (r.status >= 400 && r.status < 500) {
      const json = await r.json();
      if ("message" in json) {
        return Response.json({ message: json.message }, { status: r.status });
      } else {
        return r;
      }
    }
    if (isPostRedirect && r.status !== 302) {
      return Response.json(
        { message: "Invalid response for redirect button" },
        { status: 500 }
      );
    }
    if (isTransactionRequest) {
      const transaction = await r.json();
      return Response.json(transaction);
    }
    const htmlString = await r.text();
    const result = (0, import_frames2.getFrame)({
      htmlString,
      url: body.untrustedData.url,
      specification
    });
    return Response.json(result);
  } catch (err) {
    console.error(err);
    return Response.error();
  }
}

// src/next/FrameImage.tsx
var import_image = __toESM(require("next/image"), 1);
var import_react = __toESM(require("react"), 1);
function FrameImageNext(props) {
  return /* @__PURE__ */ import_react.default.createElement(
    import_image.default,
    {
      ...props,
      alt: props.alt ?? "",
      sizes: "100vw",
      height: 0,
      width: 0
    }
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  FrameImageNext,
  GET,
  POST
});
