"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/use-frame-stack.ts
var use_frame_stack_exports = {};
__export(use_frame_stack_exports, {
  isParseResult: () => isParseResult,
  useFrameStack: () => useFrameStack
});
module.exports = __toCommonJS(use_frame_stack_exports);
var import_react = require("react");
function isParseResult(result) {
  return "status" in result;
}
function framesStackReducer(state, action) {
  switch (action.action) {
    case "LOAD":
      return [action.item, ...state];
    case "ADD_REQUEST_DETAILS": {
      const index = state.findIndex(
        (item2) => item2.timestamp === action.pendingItem.timestamp
      );
      if (index === -1) {
        return state;
      }
      const item = state[index];
      if (!item || item.status !== "pending") {
        return state;
      }
      state[index] = {
        ...item,
        requestDetails: action.requestDetails,
        url: action.url
      };
      return state.slice();
    }
    case "DONE_REDIRECT": {
      const index = state.findIndex(
        (item) => item.timestamp === action.pendingItem.timestamp
      );
      if (index === -1) {
        return state;
      }
      state[index] = {
        ...action.pendingItem,
        ...action.item,
        status: "doneRedirect"
      };
      return state.slice();
    }
    case "DONE":
    case "REQUEST_ERROR": {
      const index = state.findIndex(
        (item) => item.timestamp === action.pendingItem.timestamp
      );
      if (index === -1) {
        return state;
      }
      state[index] = action.item;
      return state.slice();
    }
    case "RESET_INITIAL_FRAME": {
      const originalInitialFrame = state[0];
      const frame = isParseResult(action.resultOrFrame) ? action.resultOrFrame.frame : action.resultOrFrame;
      const shouldReset = !originalInitialFrame || originalInitialFrame.status === "done" && originalInitialFrame.frameResult.frame !== frame;
      if (shouldReset) {
        const frameResult = isParseResult(action.resultOrFrame) ? action.resultOrFrame : {
          status: "success",
          reports: {},
          frame: action.resultOrFrame
        };
        return [
          {
            request: {
              method: "GET",
              url: action.homeframeUrl ?? ""
            },
            url: action.homeframeUrl ?? "",
            requestDetails: {},
            response: new Response(JSON.stringify(frameResult), {
              status: 200,
              headers: { "Content-Type": "application/json" }
            }),
            responseStatus: 200,
            timestamp: /* @__PURE__ */ new Date(),
            speed: 0,
            frameResult,
            status: "done",
            // @todo should this be result or frame?
            responseBody: frameResult
          }
        ];
      }
      return state;
    }
    case "CLEAR":
      return [];
    default:
      return state;
  }
}
function useFrameStack({
  initialFrame,
  initialFrameUrl
}) {
  return (0, import_react.useReducer)(
    framesStackReducer,
    [initialFrame, initialFrameUrl],
    ([frame, frameUrl]) => {
      if (frame) {
        const frameResult = isParseResult(frame) ? frame : {
          reports: {},
          frame,
          status: "success"
        };
        return [
          {
            response: new Response(JSON.stringify(frameResult), {
              status: 200,
              headers: { "Content-Type": "application/json" }
            }),
            responseStatus: 200,
            responseBody: frameResult,
            timestamp: /* @__PURE__ */ new Date(),
            requestDetails: {},
            request: {
              method: "GET",
              url: frameUrl ?? ""
            },
            speed: 0,
            frameResult,
            status: "done",
            url: frameUrl ?? ""
          }
        ];
      } else if (frameUrl) {
        return [
          {
            method: "GET",
            request: {
              method: "GET",
              url: frameUrl
            },
            url: frameUrl,
            requestDetails: {},
            timestamp: /* @__PURE__ */ new Date(),
            status: "pending"
          }
        ];
      }
      return [];
    }
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  isParseResult,
  useFrameStack
});
