"use client";
import {
  useFetchFrame
} from "./chunk-UYO5FYWE.js";
import {
  useFrameStack
} from "./chunk-23M226IE.js";

// src/use-frame.tsx
import { useEffect, useRef, useState } from "react";
import { getFarcasterTime } from "@farcaster/core";
function onMintFallback({ target }) {
  console.log("Please provide your own onMint function to useFrame() hook.");
  const message = `Mint requested: ${target}`;
  if (typeof window !== "undefined") {
    window.alert(message);
  } else {
    console.log(message);
  }
}
var unsignedFrameAction = async ({
  buttonIndex,
  frameContext,
  frameButton,
  state,
  target,
  inputText,
  url
}) => {
  const searchParams = new URLSearchParams({
    postType: frameButton.action,
    postUrl: target ?? ""
  });
  const isFarcaster = "castId" in frameContext;
  return {
    searchParams,
    body: {
      untrustedData: {
        url,
        timestamp: isFarcaster ? getFarcasterTime()._unsafeUnwrap() : Date.now(),
        ...isFarcaster ? { network: 1 } : {},
        buttonIndex,
        state,
        inputText,
        address: frameContext.connectedAddress,
        ...frameContext
      },
      trustedData: {
        messageBytes: Buffer.from("").toString("hex")
      }
    }
  };
};
async function onTransactionFallback({
  transactionData
}) {
  console.log(
    "Please provide your own onTransaction function to useFrame() hook."
  );
  const message = `Requesting a transaction on chain with ID ${transactionData.chainId} with the following params: ${JSON.stringify(
    transactionData.params,
    null,
    2
  )}`;
  if (typeof window !== "undefined") {
    window.alert(message);
  } else {
    console.log(message);
  }
  return null;
}
function handleRedirectFallback(location) {
  console.log(
    "Please provide your own onRedirect function to useFetchFrame() hook."
  );
  const message = `You are about to be redirected to ${location.toString()}`;
  if (typeof window !== "undefined") {
    if (window.confirm(message)) {
      window.open(location, "_blank")?.focus();
    }
  } else {
    console.log(message);
  }
}
function handleLinkButtonClickFallback(button) {
  console.log(
    "Please provide your own onLinkButtonClick function to useFrame() hook."
  );
  if (typeof window !== "undefined") {
    if (window.confirm(`You are about to be redirected to ${button.target}`)) {
      parent.window.open(button.target, "_blank");
    }
  } else {
    console.log(`Link button with target ${button.target} clicked.`);
  }
}
var fallbackFrameContext = {
  castId: {
    fid: 1,
    hash: "0x0000000000000000000000000000000000000000"
  },
  address: "0x0000000000000000000000000000000000000001"
};
function useFrame({
  homeframeUrl,
  frameContext,
  dangerousSkipSigning,
  onMint = onMintFallback,
  onTransaction = onTransactionFallback,
  connectedAddress,
  signerState,
  frame,
  /** Ex: /frames */
  frameActionProxy,
  /** Ex: /frames */
  frameGetProxy,
  extraButtonRequestPayload,
  specification = "farcaster",
  onError,
  onLinkButtonClick = handleLinkButtonClickFallback,
  onRedirect = handleRedirectFallback,
  fetchFn = fetch
}) {
  const [inputText, setInputText] = useState("");
  const [framesStack, dispatch] = useFrameStack({
    initialFrame: frame,
    initialFrameUrl: homeframeUrl
  });
  const fetchFrame = useFetchFrame({
    frameActionProxy,
    frameGetProxy,
    onTransaction,
    signFrameAction(isDangerousSkipSigning, actionContext) {
      return isDangerousSkipSigning ? unsignedFrameAction(actionContext) : signerState.signFrameAction(actionContext);
    },
    specification,
    stackDispatch: dispatch,
    extraButtonRequestPayload,
    homeframeUrl,
    onError,
    fetchFn,
    onRedirect
  });
  const fetchFrameRef = useRef(fetchFrame);
  fetchFrameRef.current = fetchFrame;
  useEffect(() => {
    if (!frame && homeframeUrl) {
      fetchFrameRef.current(
        {
          url: homeframeUrl,
          method: "GET"
        },
        // tell the fetchFrame function to clear the stack because this is called only on initial render
        // and there could potentially be a pending object returned from SSR
        true
      ).catch((e) => {
        console.error(e);
      });
    } else if (frame) {
      dispatch({
        action: "RESET_INITIAL_FRAME",
        resultOrFrame: frame,
        homeframeUrl
      });
    }
  }, [frame, homeframeUrl, dispatch]);
  async function onButtonPress(currentFrame, frameButton, index, fetchFrameOverride = fetchFrame) {
    if (!signerState.hasSigner && !dangerousSkipSigning) {
      signerState.onSignerlessFramePress();
      return;
    }
    switch (frameButton.action) {
      case "link": {
        onLinkButtonClick(frameButton);
        break;
      }
      case "mint": {
        onMint({
          frameButton,
          target: frameButton.target,
          frame: currentFrame
        });
        break;
      }
      case "tx": {
        await onTransactionButton({
          frameButton,
          buttonIndex: index + 1,
          postInputText: currentFrame.inputText !== void 0 ? inputText : void 0,
          currentFrame
        });
        break;
      }
      case "post":
      case "post_redirect": {
        try {
          const target = frameButton.target || currentFrame.postUrl || homeframeUrl;
          if (!target) {
            throw new Error("missing target");
          }
          await onPostButton({
            currentFrame,
            frameButton,
            /** https://docs.farcaster.xyz/reference/frames/spec#handling-clicks
            
                    POST the packet to fc:frame:button:$idx:action:target if present
                    POST the packet to fc:frame:post_url if target was not present.
                    POST the packet to or the frame's embed URL if neither target nor action were present.
                    */
            target,
            buttonIndex: index + 1,
            postInputText: currentFrame.inputText !== void 0 ? inputText : void 0,
            state: currentFrame.state,
            fetchFrameOverride
          });
          setInputText("");
        } catch (err) {
          if (err instanceof Error) {
            onError?.(err);
          }
          console.error(err);
        }
        break;
      }
      default:
        throw new Error("Unrecognized frame button action");
    }
  }
  async function onPostButton({
    currentFrame,
    buttonIndex,
    postInputText,
    frameButton,
    target,
    state,
    transactionId,
    fetchFrameOverride
  }) {
    if (!dangerousSkipSigning && !signerState.hasSigner) {
      console.error("frames.js: missing required auth state");
      return;
    }
    if (!homeframeUrl) {
      console.error("frames.js: missing required value for post");
      return;
    }
    const _fetchFrame = fetchFrameOverride ?? fetchFrame;
    await _fetchFrame({
      frameButton,
      isDangerousSkipSigning: dangerousSkipSigning ?? false,
      method: "POST",
      signerStateActionContext: {
        inputText: postInputText,
        signer: signerState.signer ?? null,
        frameContext,
        url: homeframeUrl,
        target,
        frameButton,
        buttonIndex,
        state,
        transactionId
      },
      sourceFrame: currentFrame
    });
  }
  async function onTransactionButton({
    currentFrame,
    buttonIndex,
    postInputText,
    frameButton
  }) {
    if (!dangerousSkipSigning && !signerState.hasSigner) {
      console.error("frames.js: missing required auth state");
      return;
    }
    if (!homeframeUrl) {
      console.error("frames.js: missing required value for post");
      return;
    }
    await fetchFrame({
      frameButton,
      isDangerousSkipSigning: dangerousSkipSigning ?? false,
      method: "POST",
      signerStateActionContext: {
        inputText: postInputText,
        signer: signerState.signer ?? null,
        frameContext,
        address: connectedAddress,
        url: homeframeUrl,
        target: frameButton.target,
        frameButton,
        buttonIndex,
        state: currentFrame.state
      },
      sourceFrame: currentFrame
    });
  }
  return {
    inputText,
    setInputText,
    clearFrameStack: () => {
      dispatch({ action: "CLEAR" });
    },
    dispatchFrameStack: dispatch,
    onButtonPress,
    fetchFrame,
    homeframeUrl,
    framesStack,
    currentFrameStackItem: framesStack[0]
  };
}
export {
  fallbackFrameContext,
  unsignedFrameAction,
  useFrame
};
